import { supabase } from '@/lib/supabase/client';
import { handleAuthError } from './errors';
import type { AuthError } from '@supabase/supabase-js';

export async function signIn(email: string, password: string, rememberMe: boolean) {
  try {
    const { data, error } = await supabase.auth.signInWithPassword({
      email,
      password,
    });

    if (error) throw error;

    if (rememberMe && data.session) {
      await supabase.auth.setSession({
        access_token: data.session.access_token,
        refresh_token: data.session.refresh_token,
      });
    }

    return { user: data.user, session: data.session };
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function signUp(email: string, password: string, fullName: string) {
  try {
    const { data, error } = await supabase.auth.signUp({
      email,
      password,
      options: {
        data: { full_name: fullName },
        emailRedirectTo: `${window.location.origin}/auth/callback`,
      },
    });

    if (error) throw error;
    return { user: data.user, session: data.session };
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function signOut() {
  try {
    const { error } = await supabase.auth.signOut();
    if (error) throw error;
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function resetPassword(email: string) {
  try {
    const { error } = await supabase.auth.resetPasswordForEmail(email, {
      redirectTo: `${window.location.origin}/auth/reset-password`,
    });

    if (error) throw error;
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}